==> haskell-persistent-qq-2.12.0.6-218.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-qq
version:              2.12.0.6
visibility:           public
id:                   persistent-qq-2.12.0.6-DNfgDPeLyld1zqQKMC690F
key:                  persistent-qq-2.12.0.6-DNfgDPeLyld1zqQKMC690F
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
homepage:             https://github.com/yesodweb/persistent#readme
synopsis:             Provides a quasi-quoter for raw SQL for persistent
description:
    Please see README and API docs at <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  9331d09153eb0490e3cfd2f4286d31a7
exposed:              True
exposed-modules:      Database.Persist.Sql.Raw.QQ
hidden-modules:       Paths_persistent_qq
import-dirs:          /usr/lib/ghc-9.2.8/site-local/persistent-qq-2.12.0.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/persistent-qq-2.12.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-qq
hs-libraries:         HSpersistent-qq-2.12.0.6-DNfgDPeLyld1zqQKMC690F
depends:
    base-4.16.4.0 haskell-src-meta-0.8.12-8xbacevvo4j6DVXCUf8bas
    mtl-2.2.2 persistent-2.14.5.1-9xnFRv8rkde2AoeFkZgfdg
    template-haskell-2.18.0.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-persistent-qq/html/persistent-qq.haddock

haddock-html:         /usr/share/doc/haskell-persistent-qq/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-qq-2.12.0.6-240-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-qq
version:              2.12.0.6
visibility:           public
id:                   persistent-qq-2.12.0.6-zUhyyl2jguA9ComxDLU0c
key:                  persistent-qq-2.12.0.6-zUhyyl2jguA9ComxDLU0c
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
homepage:             https://github.com/yesodweb/persistent#readme
synopsis:             Provides a quasi-quoter for raw SQL for persistent
description:
    Please see README and API docs at <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  ec2f217cbf131bb3efddf55b4dcd837f
exposed:              True
exposed-modules:      Database.Persist.Sql.Raw.QQ
hidden-modules:       Paths_persistent_qq
import-dirs:          /usr/lib/ghc-9.2.8/site-local/persistent-qq-2.12.0.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/persistent-qq-2.12.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-qq
hs-libraries:         HSpersistent-qq-2.12.0.6-zUhyyl2jguA9ComxDLU0c
depends:
    base-4.16.4.0 haskell-src-meta-0.8.12-Fe5kGltKJxeIZkKj5WAOn4
    mtl-2.2.2 persistent-2.14.5.1-18Wt2qDE1QV8HG32f1oXLN
    template-haskell-2.18.0.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-persistent-qq/html/persistent-qq.haddock

haddock-html:         /usr/share/doc/haskell-persistent-qq/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
